<?php

define("MULTIPART_BOUNDARY", "----WebKitFormBoundary7MA4YWxkTrZu0gW");

class ESLPackageCreation {
	//Define api key and api url
	private $baseUrl = "https://sandbox.esignlive.com";
	private $url = "https://sandbox.esignlive.com/api";
	private $key = "your_api_key";
	private $senderEmail = "sender_email";

	//Constructor method for ESLPackageCreation
	public function __construct() {

	}

	//Create package
	public function buildPackage($pkgName, $pkgDesc) {
		$build = array(
			'type' => 'PACKAGE',
			'status' => 'DRAFT',
			'name' => $pkgName,
			'description' => $pkgDesc,
			'settings' => array(
				'ceremony' => array(
					'inPerson' => 'true',
				),
			),
		);
		$packageJSON = json_encode($build);
		$packageId = json_decode($this->sendRequest("/packages/", $packageJSON, NULL, NULL), true);

		$packageJSON = $this->getPackage($packageId['id']);

		return $packageJSON;
	}

	//Get package JSON
	public function getPackage($packageId) {
		$url = $this->url . '/packages/' . $packageId;
		$api_headers = array(
			'Authorization: Basic ' . $this->key,
			"Accept: application/json; esl-api-version=10.13",
		);

		$curl = curl_init($url);
		curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($curl, CURLOPT_HTTPHEADER, $api_headers);
		curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, false);
		curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
		// curl_setopt($curl, CURLOPT_PROXY, "localhost"); //your proxy url
		// curl_setopt($curl, CURLOPT_PROXYPORT, "8888"); // your proxy port number
		curl_exec($curl);
		$response = curl_multi_getcontent($curl);
		curl_close($curl);

		return $response;
	}

	//Get a session token
	public function buildSenderAuthToken($packageId) {
		$build = array(
			'packageId' => $packageId,
		);
		$tokenJSON = json_encode($build);
		$token = json_decode($this->sendRequest("/authenticationTokens/sender", $tokenJSON, NULL, 'application/json'), true);
		$designerUrl = $this->baseUrl . '/auth?senderAuthenticationToken=' . $token['value'] . '&target=' . $this->baseUrl . '/a/transaction/' . $packageId . '/designer';
		return json_encode($designerUrl);
	}

	//Get a session token
	public function buildSignerAuthToken($packageId) {
		$build = array(
			'packageId' => $packageId,
			'signerId' => $this->senderEmail,
		);
		$tokenJSON = json_encode($build);
		$token = json_decode($this->sendRequest("/authenticationTokens/signer/multiUse", $tokenJSON, NULL, 'application/json'), true);
		$signingUrl = $this->baseUrl . '/access?sessionToken=' . $token['value'];
		return array(
			'signingUrl' => $signingUrl,
		);
	}

	//Send Package
	public function buildSend($packageId) {
		$build = array(
			'status' => 'SENT',
		);
		$sendJSON = json_encode($build);
		$this->sendRequest("/packages/" . $packageId, $sendJSON, NULL, 'application/json');
		return NULL;
	}

	//cURL function to send requests to eSignLive
	private function sendRequest($type, $json, $document, $contentType) {
		if (is_null($document) && is_null($contentType)) {
			$postfields = array(
				"payload" => $json,
			);
		} else if (is_null($document) && !is_null($contentType)) {
			$postfields = $json;
		} else {
			$postfields = $document;
		}

		$headerOptions = array(
			'Authorization: Basic ' . $this->key,
			'Accept: application/json,application/zip,text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,*/*;q=0.8',
		);
		if (!is_null($contentType)) {
			$headerOptions[] = "Content-Type: $contentType";
		}

		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, $this->url . $type);
		curl_setopt($ch, CURLOPT_POST, true);
		curl_setopt($ch, CURLOPT_FAILONERROR, true);
		curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
		curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);

		// curl_setopt($ch, CURLOPT_PROXY, "http://localhost"); //your proxy url
		// curl_setopt($ch, CURLOPT_PROXYPORT, "8888"); // your proxy port number

		if (!is_null($postfields)) {
			curl_setopt($ch, CURLOPT_POSTFIELDS, $postfields);
			if (!is_array($postfields)) {
				$headerOptions[] = 'Content-Length: ' . strlen($postfields);
			}
		}

		curl_setopt($ch, CURLOPT_HTTPHEADER, $headerOptions);
		$response = curl_exec($ch);
		$err = curl_error($ch);
		curl_close($ch);

		if ($err) {
			return $err;
		} else {
			return $response;
		};
	}
}

?>